@@ -4,7 +4,6 @@
 # import classes.
 # keep this import style so you can also use the keys.Keys() etc directly.
 from ssht00ls import classes
-from ssht00ls.classes import version, SOURCE_PATH
 from ssht00ls.classes import encryption
 
 # import initialized classes.
@@ -15,8 +14,16 @@ from ssht00ls.classes.scp import scp
 from ssht00ls.classes.agent import agent
 from ssht00ls.classes.keys import keys
 from ssht00ls.classes.connections import connections
-from ssht00ls.classes.smart_cards import smart_cards, SmartCard
+from ssht00ls.classes.smartcards import smartcards, SmartCard
 from ssht00ls.classes.aliases import aliases
 from ssht00ls.classes.ssh import ssh
 from ssht00ls.classes.ssync import ssync
 
+# import objects.
+from ssht00ls.classes.client import Client
+
+# version.
+import fil3s
+SOURCE_PATH = fil3s.gfp.base(__file__)
+try: version = int(fil3s.Files.load(SOURCE_PATH+".version.py").replace("\n","").replace(" ",""))
+except: version = None
\ No newline at end of file
