@@ -4,7 +4,7 @@
 # imports.
 import os, sys, syst3m ; sys.path.insert(1, syst3m.defaults.source_path(__file__, back=2))
 os.environ["CLI"] = "True"
-os.environ["START_ENCRYPTION"] = "True"
+os.environ["INTERACTIVE"] = "True"
 from ssht00ls.classes.config import *
 import ssht00ls
 
@@ -95,7 +95,12 @@ class CLI(cl1.CLI):
 	def start(self):
 		
 		# check arguments.
-		self.arguments.check(json=JSON, exceptions=["--log-level", "--version", "--create-alias", "--non-interative"])
+		self.arguments.check(json=syst3m.defaults.options.json, exceptions=["--log-level", "--version", "--create-alias", "--non-interative"])
+
+		# sync aliases.
+		if encryption.activated:
+			response = ssht00ls.aliases.sync()
+			if not response["success"]: response.crash(json=syst3m.defaults.options.json)
 
 		#
 		# BASICS
@@ -107,7 +112,7 @@ class CLI(cl1.CLI):
 
 		# version.
 		elif self.arguments.present(['--version']):
-			self.stop(message=f"{ALIAS} version:"+Files.load(f"{SOURCE_PATH}/.version").replace("\n",""), json=syst3m.defaults.options.json)
+			self.stop(message=f"{ALIAS} version:"+Files.load(f"{SOURCE_PATH}/.version.py").replace("\n",""), json=syst3m.defaults.options.json)
 
 		# config.
 		elif self.arguments.present('--config'):
@@ -121,16 +126,16 @@ class CLI(cl1.CLI):
 			response = ssht00ls.ssh.utils.kill(
 				identifier=self.arguments.get("--kill"), 
 				sudo=self.arguments.present("--sudo"),)
-			self.stop(response=response, json=JSON)
+			self.stop(response=response, json=syst3m.defaults.options.json)
 
 		# reset cache.
 		elif self.arguments.present('--reset-cache'):
-			path = f"{HOME}/.{ALIAS}/.cache/"
+			path = cache.path
 			os.system(f"rm -fr {path}")
 			if Files.exists(path):
-				self.stop(error=f"Failed to reset cache {path}.", json=JSON)
+				self.stop(error=f"Failed to reset cache {path}.", json=syst3m.defaults.options.json)
 			else:
-				self.stop(message=f"Successfully resetted cache {path}.", json=JSON)
+				self.stop(message=f"Successfully resetted cache {path}.", json=syst3m.defaults.options.json)
 
 
 		#
@@ -202,13 +207,13 @@ class CLI(cl1.CLI):
 					if not self.arguments.present(["-f", "--forced"]) and not syst3m.console.input(f"You are deleting alias [{alias}]. Do you wish to proceed?", yes_no=True):
 						self.stop(error="Aborted.")
 					response = ssht00ls.aliases.delete(alias=alias)
-					self.stop(response=response, json=JSON)
+					self.stop(response=response, json=syst3m.defaults.options.json)
 
 				# set passphrase.
 				elif self.arguments.present('--delete'):
 					passphrase = self.get_passphrase(required=False)
 					if passphrase in [False, None, "", "null", "None", "none"]:
-						if alias_info["smart_card"]:
+						if alias_info["smartcard"]:
 							if pin != verify_pin:
 								self.stop(error="Passphrases do not match.")
 						else:
@@ -219,7 +224,7 @@ class CLI(cl1.CLI):
 						"passphrase":passphrase,
 						"pin":pin,
 					})
-					self.stop(response=response, json=JSON)
+					self.stop(response=response, json=syst3m.defaults.options.json)
 
 				# edit config.
 				elif self.arguments.present('--edit'):
@@ -233,9 +238,9 @@ class CLI(cl1.CLI):
 							utils.save_config_safely()
 						except: success = False
 						if success:
-							self.stop(message=f"Successfully renamed alias {alias} to {new_alias}.", json=JSON)
+							self.stop(message=f"Successfully renamed alias {alias} to {new_alias}.", json=syst3m.defaults.options.json)
 						else:
-							self.stop(error=f"Failed to rename alias {alias} to {new_alias}.", json=JSON)
+							self.stop(error=f"Failed to rename alias {alias} to {new_alias}.", json=syst3m.defaults.options.json)
 
 					# edit alias config.
 					else:
@@ -252,7 +257,7 @@ class CLI(cl1.CLI):
 								"private_key":self.arguments.get("--private_key", required=False, default=None),
 								"public_key":self.arguments.get("--public_key", required=False, default=None),
 								"passphrase":self.arguments.get("--passphrase", required=False, default=None),
-								"smart_card":self.arguments.get("--smart_card", format=bool, required=False, default=None),
+								"smartcard":self.arguments.get("--smartcard", format=bool, required=False, default=None),
 								"pin":self.arguments.get("--pin", format=int, required=False, default=None),
 							},
 							# the key exceptions.
@@ -261,7 +266,7 @@ class CLI(cl1.CLI):
 							value_exceptions=[None],
 							# save the edits.
 							save=True,)
-						self.stop(response=response, json=JSON)
+						self.stop(response=response, json=syst3m.defaults.options.json)
 
 				# create.
 				elif self.arguments.present('--create'):
@@ -289,7 +294,7 @@ class CLI(cl1.CLI):
 							# the keys passphrase.
 							passphrase=getpass.getpass(f"Enter the passphrase of key [{private_key}]:"),
 							# smart card.
-							smart_card=False,)
+							smartcard=False,)
 
 					# create an alias for a smart card.
 					else:
@@ -307,16 +312,16 @@ class CLI(cl1.CLI):
 							# the private port of the server.
 							private_port=self.arguments.get('--private-port', chapter="aliases", mode="--create-alias"),
 							# the path to the private key.
-							private_key=ssht00ls.smart_card.path,
+							private_key=ssht00ls.smartcard.path,
 							# smart card.
-							smart_card=True,
+							smartcard=True,
 							pin=self.arguments.get('--pin', required=False, default=None, chapter="aliases", mode="--create-alias"), )
 
 					# log to console.
-					self.stop(response=response, json=JSON)
+					self.stop(response=response, json=syst3m.defaults.options.json)
 
 				# invalid.
-				else: self.invalid(chapter="aliases", json=JSON)
+				else: self.invalid(chapter="aliases", json=syst3m.defaults.options.json)
 
 			# json show info joined.
 			if JSON and self.arguments.present('--info'):
@@ -336,7 +341,7 @@ class CLI(cl1.CLI):
 				path=self.arguments.get("--path", chapter="keys", mode="--generate"), 
 				passphrase=passphrase, 
 				comment=self.arguments.get("--comment", chapter="keys", mode="--generate"),)
-			self.stop(response=response, json=JSON)
+			self.stop(response=response, json=syst3m.defaults.options.json)
 
 		#
 		# PULL & PUSH
@@ -354,7 +359,7 @@ class CLI(cl1.CLI):
 					notes={
 						"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
 					},
-					json=JSON,)
+					json=syst3m.defaults.options.json,)
 			alias,remote = remote.split(":")
 			remote = syst3m.env.fill(remote)
 			path = syst3m.env.fill(path)
@@ -371,7 +376,7 @@ class CLI(cl1.CLI):
 				delete=self.arguments.present("--delete"), 
 				safe=self.arguments.present("--safe"), 
 				directory=True, )
-			self.stop(response=response, json=JSON)
+			self.stop(response=response, json=syst3m.defaults.options.json)
 
 		# push.
 		elif self.arguments.present('--push'):
@@ -385,7 +390,7 @@ class CLI(cl1.CLI):
 					notes={
 						"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
 					},
-					json=JSON,)
+					json=syst3m.defaults.options.json,)
 			alias,remote = remote.split(":")
 			remote = syst3m.env.fill(remote)
 			path = syst3m.env.fill(path)
@@ -402,7 +407,7 @@ class CLI(cl1.CLI):
 				delete=self.arguments.present("--delete"), 
 				safe=self.arguments.present("--safe"), 
 				directory=True, )
-			self.stop(response=response, json=JSON)
+			self.stop(response=response, json=syst3m.defaults.options.json)
 
 		#
 		# MOUNTS
@@ -420,7 +425,7 @@ class CLI(cl1.CLI):
 					notes={
 						"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
 					},
-					json=JSON,)
+					json=syst3m.defaults.options.json,)
 			alias,remote = remote.split(":")
 			remote = syst3m.env.fill(remote)
 			path = syst3m.env.fill(path)
@@ -429,7 +434,7 @@ class CLI(cl1.CLI):
 				remote=remote, 
 				path=path,
 				forced=self.arguments.present("--forced"), )
-			self.stop(response=response, json=JSON)
+			self.stop(response=response, json=syst3m.defaults.options.json)
 
 		# sync.
 		elif self.arguments.present('--sync'):
@@ -443,7 +448,7 @@ class CLI(cl1.CLI):
 					notes={
 						"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
 					},
-					json=JSON,)
+					json=syst3m.defaults.options.json,)
 			alias,remote = remote.split(":")
 			remote = syst3m.env.fill(remote)
 			path = syst3m.env.fill(path)
@@ -453,7 +458,7 @@ class CLI(cl1.CLI):
 				path=path,
 				forced=self.arguments.present("--forced"), 
 				mode="sync",)
-			self.stop(response=response, json=JSON)
+			self.stop(response=response, json=syst3m.defaults.options.json)
 
 		# unmount.
 		elif self.arguments.present('--unmount'):
@@ -462,7 +467,7 @@ class CLI(cl1.CLI):
 				path=path,
 				forced=self.arguments.present("--forced"), 
 				sudo=self.arguments.present("--sudo"), )
-			self.stop(response=response, json=JSON)
+			self.stop(response=response, json=syst3m.defaults.options.json)
 
 		# index.
 		elif self.arguments.present('--index'):
@@ -474,7 +479,7 @@ class CLI(cl1.CLI):
 			else:
 				path = syst3m.env.fill(path)
 				response = ssht00ls.ssync.index(path=index)
-			self.stop(response=response, json=JSON)
+			self.stop(response=response, json=syst3m.defaults.options.json)
 
 		#
 		# DAEMONS
@@ -492,12 +497,12 @@ class CLI(cl1.CLI):
 					notes={
 						"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
 					},
-					json=JSON,)
+					json=syst3m.defaults.options.json,)
 			alias,remote = remote.split(":")
 			remote = syst3m.env.fill(remote)
 			path = syst3m.env.fill(path)
 			response = ssht00ls.ssync.daemon(alias=alias, remote=remote, path=path)
-			self.stop(response=response, json=JSON)
+			self.stop(response=response, json=syst3m.defaults.options.json)
 
 		# stop daemon.
 		elif self.arguments.present('--stop-daemon'):
@@ -505,23 +510,23 @@ class CLI(cl1.CLI):
 			for path in self.arguments.get("--stop-daemon", index=1, chapter="daemon", mode="--stop-daemon", format=list):
 				response = ssht00ls.ssync.daemons.stop(path)
 				if not response["success"]:
-					self.stop(response=response, json=JSON)
+					self.stop(response=response, json=syst3m.defaults.options.json)
 					c += 1
 			if c > 0:
-				self.stop(message=f"Successfully stopped {c} daemon(s).", json=JSON)
+				self.stop(message=f"Successfully stopped {c} daemon(s).", json=syst3m.defaults.options.json)
 			else:
-				self.stop(error="No daemons found.", json=JSON)
+				self.stop(error="No daemons found.", json=syst3m.defaults.options.json)
 
 		# list daemons.
 		elif self.arguments.present('--list-daemons'):
 			
 			daemons = ssht00ls.ssync.daemons.status()
 			if len(daemons) == 0:
-				self.stop(message=f"There are no active daemons.", json=JSON)
+				self.stop(message=f"There are no active daemons.", json=syst3m.defaults.options.json)
 			print("Daemons:")
 			for path, status in daemons.items():
 				print(f" * {path}: {status}")
-			self.stop(message=f"Successfully listed {len(daemons)} daemon(s).", json=JSON)
+			self.stop(message=f"Successfully listed {len(daemons)} daemon(s).", json=syst3m.defaults.options.json)
 
 		# invalid.
 		else: self.invalid()
