@@ -4,75 +4,30 @@
 # imports.
 from ssht00ls.classes.config import *
 from ssht00ls.classes import utils
-from ssht00ls.classes.smart_cards import smart_cards
+from ssht00ls.classes.smartcards import smartcards
 from ssht00ls.classes.ssh import ssh
 
 # the ssh agent object class.
 class Agent(object):
-	def __init__(self):
+	def __init__(self,
+		# initialize as specific not global (optional).
+		# the path to the public key.
+		public_key=None,
+		# the path to the private key.
+		private_key=None,
+		# the smart card boolean.
+		smartcard=False,
+	):
 
-		# variables.
-		#self.initialize()
-		
-		"""# set agent.
-		self.SSH_AUTH_SOCK = os.environ.get("SSH_AUTH_SOCK")
-		self.SSH_AGENT_PID = os.environ.get("SSH_AGENT_PID")
-		if self.SSH_AUTH_SOCK == None or self.SSH_AGENT_PID == None:
-			output = subprocess.check_output(["ssh-agent"]).decode()
-			self.SSH_AUTH_SOCK = output.split("SSH_AUTH_SOCK=")[1].split(";")[0]
-			self.SSH_AGENT_PID = output.split("SSH_AGENT_PID=")[1].split(";")[0]
-			os.environ["SSH_AUTH_SOCK"] = self.SSH_AUTH_SOCK
-			os.environ["SSH_AGENT_PID"] = self.SSH_AGENT_PID
-
-		# set agent nr.2.
-		try:
-			output = utils.__execute__([f"ssh-add", "-D"])
-		except: a=1
-		try:
-			output = utils.__execute__([f"ssh-add", "-k"])
-		except: a=1
-		try:
-			output = utils.__execute__(f"ssh-agent")
-			try: 
-				SSH_AUTH_SOCK = output.split("SSH_AUTH_SOCK=")[1].split(";")[0]
-				os.environ["SSH_AUTH_SOCK"] = SSH_AUTH_SOCK
-			except: a=1
-			try: 
-				SSH_AGENT_PID = output.split("SSH_AGENT_PID=")[1].split(";")[0]
-				os.environ["SSH_AGENT_PID"] = SSH_AGENT_PID
-			except: a=1
-		except: a=1
-		"""
+		# specific variables.
+		self.specific = public_key != None or private_key != None
+		self.private_key = private_key
+		self.public_key = public_key
+		self.smartcard = smartcard
 
 		# set agent.
 		if INTERACTIVE:
 			ssh.utils.ssh_agent()
-		#if self.SSH_AUTH_SOCK == None or self.SSH_AGENT_PID == None:
-		#	utils.__execute_script__("pkill -9 -f ssh-agent")
-		#	output = subprocess.check_output(["ssh-agent"]).decode()
-		#	self.SSH_AUTH_SOCK = output.split("SSH_AUTH_SOCK=")[1].split(";")[0]
-		#	self.SSH_AGENT_PID = output.split("SSH_AGENT_PID=")[1].split(";")[0]
-		#	utils.__execute_script__("ssh-add -D")
-
-		# set agent nr.2.
-		#try:
-		#	output = utils.__execute__([f"ssh-add", "-D"])
-		#except: a=1
-		#try:
-		#	output = utils.__execute__([f"ssh-add", "-k"])
-		#except: a=1
-		#try:
-		#	output = utils.__execute__(f"ssh-agent")
-		#	try: 
-		#		SSH_AUTH_SOCK = output.split("SSH_AUTH_SOCK=")[1].split(";")[0]
-		#		os.environ["SSH_AUTH_SOCK"] = SSH_AUTH_SOCK
-		#	except: a=1
-		#	try: 
-		#		SSH_AGENT_PID = output.split("SSH_AGENT_PID=")[1].split(";")[0]
-		#		os.environ["SSH_AGENT_PID"] = SSH_AGENT_PID
-		#	except: a=1
-		#except: a=1
-
 		
 		#
 	def add(self, 
@@ -81,7 +36,7 @@ class Agent(object):
 		# the keys passphrase.
 		passphrase=None, 
 		# enable if you are using a smart card.
-		smart_card=False, 
+		smartcard=False, 
 		# the smart cards pin code
 		pin=None, 
 		# default timeout (do not use).
@@ -90,13 +45,18 @@ class Agent(object):
 		reattempt=True,
 	):
 
+		# check specific.
+		if self.specific:
+			if path == None: path = self.private_key
+			if smartcard == None: smartcard = self.smartcard
+
 		# initialize.
 		path = path.replace("//", "/")
 		response = r3sponse.check_parameters(empty_value=None, parameters={
 			"path":path
 		})
 		if not response["success"]: return response
-		if smart_card:
+		if smartcard:
 			response = r3sponse.check_parameters(empty_value=None, parameters={
 				"pin":pin
 			})
@@ -104,6 +64,9 @@ class Agent(object):
 		else:
 			if not Files.exists(path):
 				return r3sponse.error(f"Key path [{path}] does not exist.")
+			public_key = path.replace("/private_key","/public_key")
+			if not Files.exists(public_key):
+				return r3sponse.error(f"Key path [{public_key}] does not exist.")
 
 		# check agent connection.
 		output = utils.__execute__(["ssh-add", "-L"])
@@ -116,7 +79,7 @@ class Agent(object):
 					# the keys passphrase.
 					passphrase=passphrase,
 					# enable if you are using a smart card.
-					smart_card=smart_card,
+					smartcard=smartcard,
 					# the smart cards pin code
 					pin=pin,
 					# default timeout (do not use).
@@ -127,34 +90,28 @@ class Agent(object):
 			else:
 				return r3sponse.error("Failed to communicate with the ssh-agent. Try logging out the current system user & logging back in (or execute [$ eval `ssh-agent`]).")
 
+		# check already added.
+		if not smartcard:
+			response = self.check(public_key=public_key, raw=False)
+			if response.success:
+				return r3sponse.success(f"Key [{path}] is already added to the ssh agent.")
+
 		# with passphrase.
-		if smart_card or passphrase not in [False, None, "", "none", "None"]:
-			#self.initialize()
-			if smart_card:
-				path = smart_cards.path
-				if OS in ["macos"]:
-					os.system(f"rm -fr {smart_cards.path}")
-					os.system(f"cp {smart_cards.original_path} {smart_cards.path}")
-					os.system(f"chmod 644 {smart_cards.path}")
-				#file = File(path="/tmp/shell.sh")
-				#file.save(f'export SSH_AUTH_SOCK={self.SSH_AUTH_SOCK}\nexport SSH_AGENT_PID={self.SSH_AGENT_PID}\nssh-add -e {path}\nssh-add -s {path}')
-				#file.save(f'ssh-add -e {path}\nssh-add -s {path}')
-				#file.save(f'ssh-add -s {path}')
-				#file.file_path.permission.set(755)
-				#spawn = pexpect.spawn(f'sh {file.file_path.path}')
-				#file.file_path.delete(forced=True)
-				#spawn = pexpect.spawn(f'ssh-add -e {path} && ssh-add -s {path}')
-				try:
-					output = subprocess.check_output([f"ssh-add", "-e", f"{path}"])
-					print("remove card output:",output)
-				except: a=1
+		if smartcard or passphrase not in [False, None, "", "none", "None"]:
+			if smartcard:
+				path = smartcards.path
+				if syst3m.defaults.vars.os in ["macos"]:
+					os.system(f"rm -fr {smartcards.path}")
+					os.system(f"cp {smartcards.original_path} {smartcards.path}")
+					os.system(f"chmod 644 {smartcards.path}")
+				#try:
+				#	output = subprocess.check_output([f"ssh-add", "-e", f"{path}"])
+				#	print("remove card output:",output)
+				#except: a=1
 				spawn = pexpect.spawn(f'ssh-add -s {path}')
 			else:
-				#file = File(path="/tmp/shell.sh")
-				#file.save(f'export SSH_AUTH_SOCK={self.SSH_AUTH_SOCK}\nexport SSH_AGENT_PID={self.SSH_AGENT_PID}\nssh-add {path}')
-				#file.file_path.permission.set(755)
-				#spawn = pexpect.spawn(f'sh {file.file_path.path}')
-				#file.file_path.delete(forced=True)
+
+				# start.
 				spawn = pexpect.spawn(f'ssh-add {path}')
 
 			# send lines.
@@ -162,7 +119,7 @@ class Agent(object):
 			try:
 
 				# handle pincode.
-				if smart_card:
+				if smartcard:
 					spawn.expect(
 						f'Enter passphrase for PKCS#11:',
 						timeout=timeout,
@@ -199,7 +156,7 @@ class Agent(object):
 						# the keys passphrase.
 						passphrase=passphrase,
 						# enable if you are using a smart card.
-						smart_card=smart_card,
+						smartcard=smartcard,
 						# the smart cards pin code
 						pin=pin,
 						# default timeout (do not use).
@@ -214,7 +171,7 @@ class Agent(object):
 			elif output != "": 
 				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent, error: {output}")
 			else: 
-				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent.")
+				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent, error: {output}")
 
 			# handle eof.
 			"""try:
@@ -232,7 +189,7 @@ class Agent(object):
 			elif "Identity added:" in output: 
 				return r3sponse.success(f"Successfully added key [{path}] to the ssh agent.")
 			else: 
-				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent.")
+				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent, error: {output}")
 
 		#
 	def delete(self):
@@ -268,6 +225,11 @@ class Agent(object):
 		#
 	def check(self, public_key=None, raw=False):
 
+		# check specific.
+		if self.specific:
+			if public_key == None:
+				raw = False
+				public_key = self.public_key
 
 		# params.
 		response = r3sponse.check_parameters({
@@ -366,8 +328,8 @@ response = agent.add(
 
 # add a smart cards key to the agent.
 response = agent.add(
-	path=smart_card.path, 
-	smart_card=True,
+	path=smartcard.path, 
+	smartcard=True,
 	pin=123456,)
 
 # check if a key is added to the agent.
