@@ -10,13 +10,40 @@ from ssht00ls.classes.agent import agent
 class Aliases(object):
 	def __init__(self,
 		# initialize as specific not global (optional).
-		# 	the initialized alias.
+		# 	the alias.
 		alias=None,
+		# 	the username.
+		username=None,
+		# 	the public ip.
+		public_ip=None,
+		# 	the private ip.
+		private_ip=None,
+		# 	the public port.
+		public_port=None,
+		# 	the private port.
+		private_port=None,
+		# 	the path to the public key.
+		public_key=None,
+		# 	the path to the private key.
+		private_key=None,
+		# 	the smart card boolean.
+		smartcard=False,
 	):
 		
 		# specific variables.
 		self.specific = alias != None
 		self.alias = alias
+		self.username = username
+		self.public_ip = public_ip
+		self.private_ip = private_ip
+		self.public_port = public_port
+		self.private_port = private_port
+		self.private_key = private_key
+		self.public_key = public_key
+		self.smartcard = smartcard
+
+		# sync non interactive.
+		self.sync(interactive=False)
 
 		#
 	def list(self):
@@ -50,12 +77,13 @@ class Aliases(object):
 			if alias == None: alias = self.alias
 
 		# get info.
-		current_info, exists, edits = {}, False, 0
+		current_info, exists, edits = {}, True, 0
 		try: current_info = CONFIG["aliases"][alias]
 		except KeyError:
 			exists = False
 			if not create:
-				return r3sponse.error(f"Alias {alias} does not exist.")
+				return r3sponse.error(f"Alias [{alias}] does not exist.")
+
 
 		# check existing config.
 		if exists:
@@ -70,9 +98,42 @@ class Aliases(object):
 
 		# create non existant.
 		elif not exists and create:
-
+			username,public_ip,private_ip,public_port,private_port,private_key,public_key,passphrase,smartcard,pin,save,checks = Dictionary(info).unpack({
+				"username":None, 
+				"public_ip":None,
+				"private_ip":None,
+				"public_port":None,
+				"private_port":None,
+				"private_key":None,
+				"public_key":None,
+				"passphrase":None,
+				"smartcard":None,
+				"pin":None,
+				"save":True,
+				"checks":True, })
 			return self.create(
-				alias=alias,)
+				alias=alias,
+				# the users.
+				username=username, 
+				# the ip of the server.
+				public_ip=public_ip,
+				private_ip=private_ip,
+				# the port of the server.
+				public_port=public_port,
+				private_port=private_port,
+				# the path to the private & public key.
+				private_key=private_key,
+				public_key=public_key,
+				# the keys passphrase.
+				passphrase=passphrase,
+				# smart card.
+				smartcard=smartcard,
+				# the smart cards pincode.
+				pin=pin,
+				# save to configuration.
+				save=save,
+				# do checks.
+				checks=checks, )
 
 		# save edits.
 		if edits > 0:
@@ -125,7 +186,7 @@ class Aliases(object):
 		# save the edits.
 		save=True,
 		# the log level.
-		log_level=LOG_LEVEL,
+		log_level=syst3m.defaults.options.log_level,
 	):
 		def edit_dict(dictionary={}, edits={}):
 			c = 0
@@ -148,17 +209,50 @@ class Aliases(object):
 					dictionary[key] = value
 					c += 1
 			return dictionary, c
+		
 		# check specific.
 		if self.specific:
 			if alias == None: alias = self.alias
+		
+		# passphrase.
+		edits = 0
+		if "passphrase" in list(edits.keys()) and edits["passphrase"] not in value_exceptions:
+			# check encryption activated.
+			if edits["passphrase"] not in [False, "", "none", "None"]:
+				if not encryption.activated:
+					return r3sponse.error("The encryption requires to be activated.")
+				response = encryption.encryption.encrypt(edits["passphrase"])
+				if not response["success"]: return response
+				CONFIG["aliases"][alias]["smartcard"] = False
+				CONFIG["aliases"][alias]["passphrase"] = response.encrypted.decode()
+			else:
+				CONFIG["aliases"][alias]["smartcard"] = True
+				CONFIG["aliases"][alias]["passphrase"] = ""
+			edits += 1
+			del edits["passphrase"]
+		
+		# pin.
+		if "pin" in list(edits.keys()) and edits["pin"] not in value_exceptions:
+			# check encryption activated.
+			if edits["pin"] not in [False, "", "none", "None"]:
+				if not encryption.activated:
+					return r3sponse.error("The encryption requires to be activated.")
+				response = encryption.encryption.encrypt(edits["pin"])
+				if not response["success"]: return response
+				CONFIG["aliases"][alias]["smartcard"] = True
+				CONFIG["aliases"][alias]["pin"] = response.encrypted.decode()
+			else:
+				CONFIG["aliases"][alias]["pin"] = ""
+			del edits["pin"]
+
 		# check.
 		response = self.check(alias)
 		if not response["success"]: return response
-		dictionary, c = edit_dict(dictionary=CONFIG.dictionary, edits=edits)
-		if c > 0 and save:
-			CONFIG.dictionary = dictionary
+		dictionary, c = edit_dict(dictionary=CONFIG["aliases"][alias], edits=edits)
+		if (edits > 0 or c > 0) and save:
+			CONFIG["aliases"][alias] = dictionary
 			utils.save_config_safely()
-		if c > 0:
+		if edits > 0 or c > 0:
 			return r3sponse.success(f"Successfully saved {c} edits for alias {alias}.")
 		else:
 			return r3sponse.error(f"No edits were specified.")
@@ -179,7 +273,7 @@ class Aliases(object):
 		# the keys passphrase.
 		passphrase=None,
 		# smart card.
-		smart_card=False,
+		smartcard=None,
 		# the smart cards pincode.
 		pin=None,
 		# save to configuration.
@@ -190,9 +284,21 @@ class Aliases(object):
 		serialized={},
 	):
 
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+			if username == None: username = self.username
+			if public_ip == None: public_ip = self.public_ip
+			if private_ip == None: private_ip = self.private_ip
+			if public_port == None: public_port = self.public_port
+			if private_port == None: private_port = self.private_port
+			if private_key == None: private_key = self.private_key
+			if public_key == None: public_key = self.public_key
+			if smartcard == None: smartcard = self.smartcard
+
 		# serialized
 		if serialized != {}:
-			username, public_ip, private_ip, public_port, private_port, private_key, public_key, passphrase, smart_card, pin, alias = Dictionary(serialized).unpack({
+			username, public_ip, private_ip, public_port, private_port, private_key, public_key, passphrase, smartcard, pin, alias = Dictionary(serialized).unpack({
 				"username":None,
 				"public_ip":None,
 				"private_ip":None,
@@ -201,7 +307,7 @@ class Aliases(object):
 				"private_key":None,
 				"public_key":None,
 				"passphrase":None,
-				"smart_card":None,
+				"smartcard":None,
 				"pin":None,
 				"alias":None,
 			})
@@ -220,9 +326,10 @@ class Aliases(object):
 			"private_port":private_port,
 			"private_key":private_key,
 			"public_key":public_key,
+			#"smartcard:bool":smartcard,
 		}, empty_value=None)
 		if not response["success"]: return response
-		if smart_card:
+		if smartcard:
 			response = r3sponse.check_parameters({
 				"pin":pin,
 			}, empty_value=None)
@@ -234,7 +341,7 @@ class Aliases(object):
 			if not response["success"]: return response
 
 		# check encryption activated.
-		if not encryption.activated:
+		if checks and not encryption.activated:
 			return r3sponse.error("The encryption requires to be activated.")
 
 		# duplicate.
@@ -273,28 +380,29 @@ class Aliases(object):
 		config += "\n    PubKeyAuthentication yes"
 		#config += "\n    IdentitiesOnly yes"
 		json_config["public_key"] = public_key
-		if not smart_card:
+		if not smartcard:
 			json_config["private_key"] = private_key
-			json_config["smart_card"] = False
+			json_config["smartcard"] = False
 			config += "\n    IdentityFile {}".format(private_key)
 		else:
-			json_config["private_key"] = smart_cards.path
-			json_config["smart_card"] = True
-			config += "\n    PKCS11Provider {}".format(smart_cards.path)
+			json_config["private_key"] = smartcards.path
+			json_config["smartcard"] = True
+			config += "\n    PKCS11Provider {}".format(smartcards.path)
 
 		# passphrase.
-		if passphrase not in [False, "", "none", None, "None"]:
-			if smart_card:
-				response = encryption.encryption.encrypt(str(pin))
-				if not response["success"]: return response
-				json_config["pin"] = response["encrypted"].decode()
+		if save:
+			if passphrase not in [False, "", "none", None, "None"]:
+				if smartcard:
+					response = encryption.encryption.encrypt(str(pin))
+					if not response["success"]: return response
+					json_config["pin"] = response["encrypted"].decode()
+				else:
+					response = encryption.encryption.encrypt(str(passphrase))
+					if not response["success"]: return response
+					json_config["passphrase"] = response["encrypted"].decode()
 			else:
-				response = encryption.encryption.encrypt(str(passphrase))
-				if not response["success"]: return response
-				json_config["passphrase"] = response["encrypted"].decode()
-		else:
-			json_config["passphrase"] = ""
-			json_config["pin"] = ""
+				json_config["passphrase"] = ""
+				json_config["pin"] = ""
 
 		# save.
 		if save:
@@ -306,21 +414,43 @@ class Aliases(object):
 			"json":json_config,
 			"str":config,
 		})
-	def sync(self):
-		if not Files.exists(f"{HOME}/.ssh"): os.system(f"mkdir {HOME}/.ssh && chown -R {OWNER}:{GROUP} {HOME}/.ssh && chmod 700 {HOME}/.ssh")
-		# check encryption activated.
-		if not encryption.activated:
-			return r3sponse.error("The encryption requires to be activated.")
+	def sync(self, aliases=["*"], interactive=None):
+		if interactive == None: interactive = INTERACTIVE
+
+		# all aliases.
+		if "*" in aliases or "all" in aliases:
+			if self.specific:
+				aliases = [self.alias]
+			else:
+				aliases = list(CONFIG["aliases"].keys())
+		_aliases_ = list(aliases)
+			
+		# check ssh dir.
+		if not Files.exists(f"{syst3m.defaults.vars.home}/.ssh"): os.system(f"mkdir {syst3m.defaults.vars.home}/.ssh && chown -R {syst3m.defaults.vars.user}:{syst3m.defaults.vars.group} {syst3m.defaults.vars.home}/.ssh && chmod 700 {syst3m.defaults.vars.home}/.ssh")
+		
+		# check include.
 		include = f"include ~/.ssht00ls/lib/aliases"
-		if not Files.exists(f"{HOME}/.ssh/config"): 
-			Files.save(f"{HOME}/.ssh/config", include)
-			os.system(f"chown {OWNER}:{GROUP} {HOME}/.ssh/config && chmod 770 {HOME}/.ssh/config")
-		if include not in Files.load(f"{HOME}/.ssh/config"):
-			Files.save(f"{HOME}/.ssh/config", Files.load(f"{HOME}/.ssh/config")+"\n"+include+"\n")
+		if not Files.exists(f"{syst3m.defaults.vars.home}/.ssh/config"): 
+			Files.save(f"{syst3m.defaults.vars.home}/.ssh/config", include)
+			os.system(f"chown {syst3m.defaults.vars.user}:{syst3m.defaults.vars.group} {syst3m.defaults.vars.home}/.ssh/config && chmod 770 {syst3m.defaults.vars.home}/.ssh/config")
+		if include not in Files.load(f"{syst3m.defaults.vars.home}/.ssh/config"):
+			data = Files.load(f"{syst3m.defaults.vars.home}/.ssh/config")
+			new, included = "", False
+			for line in data.split("\n"):
+				if len(line) > 0 and line[0] == "#":
+					a=1
+				elif not included:
+					new += include+"\n"
+					included = True
+				new += line+"\n"
+			Files.save(f"{syst3m.defaults.vars.home}/.ssh/config", new)
+
+		# iterate.
 		aliases, c = "", 0
-		for alias in list(CONFIG["aliases"].keys()):
+		for alias in _aliases_:
 			info = CONFIG["aliases"][alias]
 			if "example.com " not in alias:
+				
 				# deprications.
 				if "user" in info:
 					user = info["user"]
@@ -328,6 +458,11 @@ class Aliases(object):
 					info["username"] = user
 					CONFIG["aliases"][alias]["user"] = user
 					utils.save_config_safely()
+				
+				# check existance.
+				response = self.check(alias=alias)
+				if not response.success: return response
+
 				# proceed.
 				checked = Dictionary(path=False, dictionary=info).check(default={
 					"username":None,
@@ -338,22 +473,30 @@ class Aliases(object):
 					"private_key":None,
 					"public_key":None,
 					"passphrase":None,
-					"smart_card":None,
+					"smartcard":None,
 					"pin":None,
 				})
+				if Dictionary(checked) != Dictionary(CONFIG["aliases"][alias]):
+					CONFIG["aliases"][alias] = checked
+					utils.save_config_safely()
 				if isinstance(checked["private_key"], str):
 					checked["private_key"] = syst3m.env.fill(checked["private_key"])
+					Files.chmod(checked["private_key"], permission=700)
 				if isinstance(checked["public_key"], str):
 					checked["public_key"] = syst3m.env.fill(checked["public_key"])
-				if not cl1.argument_present("--non-interactive"):
+					Files.chmod(checked["public_key"], permission=700)
+				if interactive:
 					passphrase, has_passphrase, new_passphrase = None, True, True
-					if checked["smart_card"] == True:
+					if checked["smartcard"] == True:
 						if checked["pin"] in [False, None, "", "none", "None"]:
 							if checked["pin"] in [False, "", "none", "None"]:
 								has_passphrase = False
 							else:
 								passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['private_key']}:")
 						else:
+							# check encryption activated.
+							if not encryption.activated:
+								return r3sponse.error("The encryption requires to be activated.")
 							new_passphrase = False
 							response = encryption.encryption.decrypt(checked["pin"])
 							if not response.success: return response
@@ -365,28 +508,34 @@ class Aliases(object):
 							else:
 								passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['private_key']}:")
 						else:
+							# check encryption activated.
+							if not encryption.activated:
+								return r3sponse.error("The encryption requires to be activated.")
 							new_passphrase = False
 							response = encryption.encryption.decrypt(checked["passphrase"])
 							if not response.success: return response
 							passphrase = response.decrypted.decode()
 					if has_passphrase:
-						if checked["smart_card"] == True:
+						if checked["smartcard"] == True:
 							response = agent.check(public_key=checked["public_key"], raw=True)
 						else:
 							response = agent.check(public_key=checked["public_key"], raw=False)
 						if not response["success"]:
 							if "is not added" not in response["error"]: return response
 							elif "is not added" in response["error"]:
-								if checked["smart_card"]:
-									response = agent.add(path=checked["private_key"], smart_card=True, pin=passphrase)
+								if checked["smartcard"]:
+									response = agent.add(path=checked["private_key"], smartcard=True, pin=passphrase)
 									if not response["success"]: return response
 								else:
 									response = agent.add(path=checked["private_key"], passphrase=passphrase)
 									if not response["success"]: return response
 						if new_passphrase:
+							# check encryption activated.
+							if not encryption.activated:
+								return r3sponse.error("The encryption requires to be activated.")
 							response = encryption.encryption.encrypt(passphrase)
 							if not response.success: return response
-							if checked["smart_card"] == True:
+							if checked["smartcard"] == True:
 								CONFIG["aliases"][alias]["pin"] = response.encrypted.decode()
 							else:
 								CONFIG["aliases"][alias]["passphrase"] = response.encrypted.decode()
@@ -395,7 +544,11 @@ class Aliases(object):
 				if not response["success"]: return response
 				aliases += response["str"]
 				c += 1
-		Files.save(f"{HOME}/.ssht00ls/lib/aliases", aliases)
+
+		# save lib.
+		Files.save(f"{syst3m.defaults.vars.home}/.ssht00ls/lib/aliases", aliases)
+
+		# handler.
 		return r3sponse.success(f"Successfully synchronized {c} alias(es).")
 
 # initialized objects.
@@ -420,7 +573,7 @@ response = aliases.create(self,
 	# the path to the private key.
 	key="/path/to/mykey/private_key",
 	# smart card.
-	smart_card=False,)
+	smartcard=False,)
 # if successfull you can use the ssh alias <username>.<server>
 # $ ssh <username>.<server>
 
@@ -435,9 +588,9 @@ response = aliases.create(self,
 	# the port of the server.
 	port=22,
 	# the path to the private key.
-	key=smart_card.path,
+	key=smartcard.path,
 	# smart card.
-	smart_card=True,)
+	smartcard=True,)
 
 ```
 
