@@ -8,7 +8,7 @@ ALIAS = "ssht00ls"
 import os, sys
 try: import cl1
 except ImportError: 
-	if os.path.exists("/usr/bin/pip3"): os.system(f"/usr/bin/pip3 install cl1 --user {OWNER}")
+	if os.path.exists("/usr/bin/pip3"): os.system(f"/usr/bin/pip3 install cl1 --user {syst3m.defaults.vars.user}")
 	else: os.system(f"pip3 install cl1")
 	import cl1
 if cl1.arguments_present(["--update"]):
@@ -30,7 +30,7 @@ try:
 except ImportError as e:
 	import os
 	if os.path.exists("/usr/bin/pip3"): 
-		os.system(f"/usr/bin/pip3 install -r {syst3m.defaults.source_path(__file__, back=3)}/requirements/requirements.txt --user {os.environ.get('USER')}")
+		os.system(f"/usr/bin/pip3 install -r {syst3m.defaults.source_path(__file__, back=3)}/requirements/requirements.txt --user {os.environ.get('syst3m.defaults.vars.user')}")
 	else:
 		os.system(f"pip3 install -r {syst3m.defaults.source_path(__file__, back=3)}/requirements/requirements.pip")
 
@@ -46,40 +46,42 @@ except ImportError as e:
 # source.	
 SOURCE_PATH = syst3m.defaults.source_path(__file__, back=3)
 BASE = syst3m.defaults.source_path(SOURCE_PATH)
-OS = syst3m.defaults.operating_system(supported=["linux", "macos"])
-LOG_LEVEL = syst3m.defaults.log_level(default=0)
+syst3m.defaults.operating_system(supported=["linux", "macos"])
 syst3m.defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
+if syst3m.defaults.options.log_level >= 1:
+	r3sponse.log(f"{ALIAS} source: {SOURCE_PATH}")
+	r3sponse.log(f"{ALIAS} os: {syst3m.defaults.vars.os}")
 
 # universal options.
-CLI = syst3m.env.get_boolean("CLI")
-INTERACTIVE = not cl1.arguments_present(["--non-interactive"]) and not syst3m.env.get_boolean("NON_INTERACTIVE")
+# interactive must be False by default.
+INTERACTIVE = syst3m.env.get("INTERACTIVE", format=bool, default=False)
+CLI = syst3m.env.get("CLI", format=bool, default=False)
 CHECKS = not cl1.arguments_present(["--no-checks"])
-JSON = cl1.arguments_present(["-j", "--json"])
-print("INTERACTIVE:",INTERACTIVE)
+RESET_CACHE = cl1.arguments_present("--reset-cache")
+if syst3m.defaults.options.log_level >= 1:
+	r3sponse.log(f"{ALIAS} cli: {CLI}")
+	r3sponse.log(f"{ALIAS} interactive: {INTERACTIVE}")
+	r3sponse.log(f"{ALIAS} checks: {CHECKS}")
 
-# version.
-try: version = Files.load(f"{SOURCE_PATH}/.version")
-except: version = "unkown"
+# database.
+DATABASE = Directory(path=syst3m.env.get_string("SSHT00LS_DATABASE", default=f"{syst3m.defaults.vars.home}/.{ALIAS}"))
+if not DATABASE.fp.exists():
+	r3sponse.log(f"{syst3m.color.orange}Root permission{syst3m.color.end} required to create ssht00ls database [{DATABASE}].")
+	os.system(f" sudo mkdir -p {DATABASE}")
+	Files.chown(str(DATABASE), owner=syst3m.defaults.vars.owner, group=syst3m.defaults.vars.group, sudo=True, recursive=True)
+	Files.chmod(str(DATABASE), permission=700, sudo=True, recursive=True)
 
-# universal variables.
-USER = OWNER = os.environ.get("USER")
-GROUP = "root"
-HOME_BASE = "/home/"
-HOME = f"/home/{USER}/"
-MEDIA = f"/media/{USER}/"
-if OS in ["macos"]: 
-	HOME_BASE = "/Users/"
-	HOME = f"/Users/{USER}/"
-	MEDIA = f"/Volumes/"
-	GROUP = "wheel"
+# config.
+CONFIG = Dictionary(path=syst3m.env.get_string("SSHT00LS_CONFIG", default=DATABASE.join("config","")), load=True, default={})
+
+# logs.
+if syst3m.defaults.options.log_level >= 1:
+	r3sponse.log(f"{ALIAS} database: {DATABASE}")
+	r3sponse.log(f"{ALIAS} config: {CONFIG.fp}")
 
 # initialize cache.
 cache = syst3m.cache.Cache(
-	path=f"{HOME}/.{ALIAS}/.cache/",)
-
-# files.
-DATABASE = Files.Directory(path=f"{HOME}/.{ALIAS}")
-CONFIG = Dictionary(path=syst3m.env.fill(syst3m.env.get_string("SSHT00LS_CONFIG", default=DATABASE.join("config",""))), load=True, default={})
+	path=gfp.clean(f"{DATABASE}/.cache/"))
 
 # netw0rk settings.
 IPINFO_API_KEY = os.environ.get("IPINFO_API_KEY")
@@ -92,14 +94,23 @@ DEFAULT_SSH_OPTIONS = f"-o ConnectTimeout={SSH_TIMEOUT} -o ConnectionAttempts={S
 # daemon settings.
 SSYNC_DAEMON_SLEEPTIME = round(float(cl1.get_argument("--daemon-sleeptime", required=False, default=0.25)), 2)
 
+# logs.
+if syst3m.defaults.options.log_level >= 2:
+	r3sponse.log(f"{ALIAS} ssh timeout: {SSH_TIMEOUT}")
+	r3sponse.log(f"{ALIAS} ssh reattempts: {SSH_REATTEMPS}")
+	r3sponse.log(f"{ALIAS} daemon sleeptime: {SSYNC_DAEMON_SLEEPTIME}")
+
 # speed up non interactive.
-if CHECKS and not cl1.arguments_present("--reset-cache"):
+if CHECKS and not RESET_CACHE:
 
 	# network.
 	NETWORK_INFO = netw0rk.network.info()
 	if not NETWORK_INFO["success"]: 
 		r3sponse.log(error=NETWORK_INFO.error, json=cl1.arguments_present(["--json", "-j"]), log_level=0)
 		sys.exit(1)
+	if syst3m.defaults.options.log_level >= 1:
+		r3sponse.log(f"public ip: {NETWORK_INFO['public_ip']}")
+		r3sponse.log(f"private ip: {NETWORK_INFO['private_ip']}")
 
 	# check lib.
 	if not Files.exists(f"{SOURCE_PATH}/lib"):
@@ -115,14 +126,15 @@ if CHECKS and not cl1.arguments_present("--reset-cache"):
 
 	# database.
 	for dir, permission in [
-		[f"{HOME}/.{ALIAS}", 770],
-		[f"{HOME}/.{ALIAS}/lib", 770],
-		[f"{HOME}/.{ALIAS}/.cache", 770],
+		[f"{syst3m.defaults.vars.home}/.{ALIAS}", 770],
+		[f"{syst3m.defaults.vars.home}/.{ALIAS}/lib", 770],
+		[f"{syst3m.defaults.vars.home}/.{ALIAS}/.cache", 770],
 	]:
-		if not Files.exists(dir): os.system(f"sudo mkdir {dir} && sudo chown {OWNER}:{GROUP} {dir} && sudo chmod {permission} {dir}")
+		if not Files.exists(dir): 
+			os.system(f"sudo mkdir {dir} && sudo chown {syst3m.defaults.vars.user}:{syst3m.defaults.vars.group} {dir} && sudo chmod {permission} {dir}")
 
 	# files.
-	CONFIG.check(default={
+	CONFIG.check(save=True, default={
 		"aliases":{
 			"example.com (key's are optional)":{
 				"username":"administrator",
@@ -133,7 +145,7 @@ if CHECKS and not cl1.arguments_present("--reset-cache"):
 				"private_key":"~/keys/example.com/administrator/private_key",
 				"public_key":"~/keys/example.com/administrator/public_key",
 				"passphrase":None,
-				"smart_card":False,
+				"smartcard":False,
 				"pin":None,
 			}
 		},
@@ -146,8 +158,12 @@ if CHECKS and not cl1.arguments_present("--reset-cache"):
 		},
 	})
 
+	# database.
+	Files.chmod(f"{SOURCE_PATH}/classes/utils/isdir.py", permission=777)
+	Files.chmod(f"{SOURCE_PATH}/classes/utils/size.py", permission=777)
+
 	# limit webserver recursive import.
-	if not syst3m.env.get("SSHT00LS_WEBSERVER_IMPORT", format=bool):
+	if syst3m.env.get("SSHT00LS_WEBSERVER_IMPORT", default=False, format=bool) not in ["True", True]:
 
 		# webserver.
 		from ssht00ls.classes.webserver import WebServer
@@ -162,26 +178,36 @@ if CHECKS and not cl1.arguments_present("--reset-cache"):
 				sys.exit(1)
 		elif cl1.argument_present("--start-agent"):
 			if not webserver.running(): 
+				if syst3m.defaults.options.log_level >= 1:
+					r3sponse.log(f"{ALIAS}: starting the ssht00ls agent.")
 				webserver.start()
 				sys.exit(0)
 			else:
 				r3sponse.log(error=f"The {webserver.id} is already running.", json=syst3m.defaults.options.json)
 				sys.exit(1)
 		elif INTERACTIVE and not webserver.running(): 
+			if syst3m.defaults.options.log_level >= 1:
+				r3sponse.log(f"{ALIAS}: forking the ssht00ls agent.")
 			response = webserver.fork()
 			r3sponse.log(response=response, json=syst3m.defaults.options.json)
-			if not response.success: sys.exit(0)
+			if not response.success: sys.exit(1)
+		if syst3m.defaults.options.log_level >= 1:
+			r3sponse.log(f"{ALIAS} webserver: {webserver}")
 
 		# encryption.
 		from ssht00ls.classes import encryption as _encryption_
 		encryption = _encryption_.Encryption(
 			config=CONFIG,
 			webserver=webserver,
-			cache=f"{syst3m.defaults.vars.home}/.{ALIAS}/.cache.enc/",
+			cache=cache.path,
 			interactive=INTERACTIVE,)
+		if syst3m.defaults.options.log_level >= 1:
+			r3sponse.log(f"{ALIAS} encryption: {encryption}")
 
-		# generate.
+		# check interactive.
 		if INTERACTIVE:
+
+			# generate encryption.
 			if None in [CONFIG.dictionary["encryption"]["public_key"], CONFIG.dictionary["encryption"]["private_key"]]:
 				if CLI:
 					response = encryption.generate()
@@ -191,11 +217,14 @@ if CHECKS and not cl1.arguments_present("--reset-cache"):
 					r3sponse.log(error="There is no encryption installed.", json=syst3m.defaults.options.json)
 					sys.exit(1)
 
-			# activate.
+			# activate encryption.
 			else:
-
-				# activate encryption.
 				response = encryption.activate()
 				r3sponse.log(response=response, json=syst3m.defaults.options.json)
 				if not response.success: sys.exit(1)
 
+	elif syst3m.defaults.options.log_level >= 0:
+		r3sponse.log(f"{ALIAS}: skip encryption import (#2) due to ssht00ls agent start.")
+elif syst3m.defaults.options.log_level >= 0:
+	r3sponse.log(f"{ALIAS}: skip encryption import (#1) due to ssht00ls agent start.")
+
