@@ -14,8 +14,8 @@ class Installation(object):
 		username=None,
 	):
 		# initialize.
-		if username == None: username = OWNER
-		home = f"{HOME_BASE}/{username}/"	
+		if username == None: username = syst3m.defaults.vars.user
+		home = f"{syst3m.defaults.vars.homes}/{username}/"	
 		sudo = True
 		
 		# users ssh directory.
@@ -83,8 +83,8 @@ class Installation(object):
 	):	
 
 		# initialize.
-		if username == None: username = OWNER
-		home = f"{HOME_BASE}/{username}/"	
+		if username == None: username = syst3m.defaults.vars.user
+		home = f"{syst3m.defaults.vars.homes}/{username}/"	
 		sudo = True
 		
 		# users ssh directory.
