@@ -4,29 +4,32 @@
 # imports.
 from ssht00ls.classes.config import *
 from ssht00ls.classes import utils
-from ssht00ls.classes.smart_cards import smart_cards
+from ssht00ls.classes.smartcards import smartcards
 
 # the ssh key object class.
 class Keys(object):
 	def __init__(self,
 		# initialize as specific not global (optional).
-		# 	the key's path.
-		path=None,
 		#	the username.
 		username=None,
+		# the path to the public key.
+		public_key=None,
+		# the path to the private key.
+		private_key=None,
 	):
 
 		# specific variables.
-		self.specific = path != None
-		self.path = path
+		self.specific = username != None
 		self.username = username
+		self.private_key = private_key
+		self.pubic_key = public_key
 
 		#
 	def edit_passphrase(self, path=None, old=None, new=None):
 
 		# check specific.
 		if self.specific:
-			if path == None: path = self.path
+			if path == None: path = self.private_key
 
 		# checks.
 		path = Formats.denitialize(path)
@@ -67,7 +70,7 @@ class Keys(object):
 
 		# check specific.
 		if self.specific:
-			if path == None: path = self.path
+			if path == None: path = self.private_key
 
 		# checks.
 		path = Formats.denitialize(path)
@@ -108,7 +111,7 @@ class Keys(object):
 
 		# check specific.
 		if self.specific:
-			if path == None: path = self.path
+			if path == None: path = gfp.base(path=self.private_key)
 
 		# checks.
 		directory = Formats.denitialize(path)
@@ -132,7 +135,7 @@ class Keys(object):
 		elif not Files.exists(directory): 
 			os.mkdir(directory)
 			Files.chmod(path=directory, permission=700, sudo=True)
-			Files.chown(path=directory, owner=os.environ.get("USER"), group=None, sudo=True)
+			Files.chown(path=directory, owner=os.environ.get("syst3m.defaults.vars.user"), group=None, sudo=True)
 
 		# options.
 		private_key = f'{directory}/private_key'
@@ -150,12 +153,12 @@ class Keys(object):
 
 		# permissions.
 		Files.chmod(path=private_key, permission=600, sudo=True)
-		Files.chown(path=private_key, owner=os.environ.get("USER"), group=None, sudo=True)
+		Files.chown(path=private_key, owner=os.environ.get("syst3m.defaults.vars.user"), group=None, sudo=True)
 		os.system(f"mv '{private_key}.pub' '{public_key}'")
 		if not Files.exists(public_key): 
 			return r3sponse.error(f"Failed to move private key [{private_key}].")
 		Files.chmod(path=public_key, permission=640, sudo=True)
-		Files.chown(path=public_key, owner=os.environ.get("USER"), group=None, sudo=True)
+		Files.chown(path=public_key, owner=os.environ.get("syst3m.defaults.vars.user"), group=None, sudo=True)
 
 		# response.
 		return r3sponse.success(f"Successfully generated key [{directory}].")
@@ -168,10 +171,10 @@ class Keys(object):
 			if username == None: username = self.username
 
 		# check if already present.
-		if username == None: username = OWNER
+		if username == None: username = syst3m.defaults.vars.user
 		username = Formats.denitialize(username)
-		ssh_dir = FilePath(f"{HOME_BASE}/{username}/.ssh/")
-		auth_keys = FilePath(f"{HOME_BASE}/{username}/.ssh/authorized_keys")
+		ssh_dir = FilePath(f"{syst3m.defaults.vars.homes}/{username}/.ssh/")
+		auth_keys = FilePath(f"{syst3m.defaults.vars.homes}/{username}/.ssh/authorized_keys")
 		output = self.__load_keys__(username)
 		for key in public_keys:
 			key = key.replace("\n", "")
@@ -205,9 +208,11 @@ class Keys(object):
 		# check specific.
 		if self.specific:
 			if username == None: username = self.username
+			if public_keys == []:
+				public_keys = Array(Files.load(self.public_key).split("\n")).clean(remove_first=[" "], remove_last=[" "])
 
 		# check if already present.
-		if username == None: username = OWNER
+		if username == None: username = syst3m.defaults.vars.user
 		output = self.__load_keys__(username)
 		new_keys = []
 		for key in public_keys:
@@ -230,9 +235,11 @@ class Keys(object):
 		# check specific.
 		if self.specific:
 			if username == None: username = self.username
+			if public_keys == []:
+				public_keys = Array(Files.load(self.public_key).split("\n")).clean(remove_first=[" "], remove_last=[" "])
 
 		# check if already present.
-		if username == None: username = OWNER
+		if username == None: username = syst3m.defaults.vars.user
 		output = self.__load_keys__(username)
 		new_keys = []
 		for key in output:
@@ -252,10 +259,10 @@ class Keys(object):
 	def __load_keys__(self, username):
 
 		# make readable.
-		if username == None: username = OWNER
-		sudo = OWNER != username or True
-		ssh_dir = FilePath(f"{HOME_BASE}/{username}/.ssh/")
-		auth_keys = FilePath(f"{HOME_BASE}/{username}/.ssh/authorized_keys")
+		if username == None: username = syst3m.defaults.vars.user
+		sudo = syst3m.defaults.vars.user != username or True
+		ssh_dir = FilePath(f"{syst3m.defaults.vars.homes}/{username}/.ssh/")
+		auth_keys = FilePath(f"{syst3m.defaults.vars.homes}/{username}/.ssh/authorized_keys")
 
 		# checks.
 		if not ssh_dir.exists(sudo=sudo):
@@ -276,22 +283,22 @@ class Keys(object):
 
 		ssh_dir.permission.set(permission=770, sudo=sudo, silent=True) # silent for when non existant.
 		auth_keys.permission.set(permission=770, sudo=sudo, silent=True) # silent for when non existant.
-		auth_keys.ownership.set(owner=OWNER, sudo=sudo)
-		ssh_dir.ownership.set(owner=OWNER, sudo=sudo)
+		auth_keys.ownership.set(owner=syst3m.defaults.vars.user, sudo=sudo)
+		ssh_dir.ownership.set(owner=syst3m.defaults.vars.user, sudo=sudo)
 
 		if sudo: command = ["sudo"]
 		else: command = []
-		output = utils.__execute__(command + ["cat", f"{HOME_BASE}/{username}/.ssh/authorized_keys"], return_format="array")
+		output = utils.__execute__(command + ["cat", f"{syst3m.defaults.vars.homes}/{username}/.ssh/authorized_keys"], return_format="array")
 		return output
 
 		#
 	def __save_keys__(self, username, public_keys):
 
 		# make readable.
-		if username == None: username = OWNER
-		sudo = OWNER != username or True
-		ssh_dir = FilePath(f"{HOME_BASE}/{username}/.ssh/")
-		auth_keys = FilePath(f"{HOME_BASE}/{username}/.ssh/authorized_keys")
+		if username == None: username = syst3m.defaults.vars.user
+		sudo = syst3m.defaults.vars.user != username or True
+		ssh_dir = FilePath(f"{syst3m.defaults.vars.homes}/{username}/.ssh/")
+		auth_keys = FilePath(f"{syst3m.defaults.vars.homes}/{username}/.ssh/authorized_keys")
 
 		# checks.
 		if not ssh_dir.exists(sudo=sudo):
@@ -319,8 +326,8 @@ class Keys(object):
 
 		ssh_dir.permission.set(permission=700, sudo=sudo, silent=True) # silent for when non existant.
 		auth_keys.permission.set(permission=600, sudo=sudo, silent=True) # silent for when non existant.
-		auth_keys.ownership.set(owner=OWNER, sudo=sudo)
-		ssh_dir.ownership.set(owner=OWNER, sudo=sudo)
+		auth_keys.ownership.set(owner=syst3m.defaults.vars.user, sudo=sudo)
+		ssh_dir.ownership.set(owner=syst3m.defaults.vars.user, sudo=sudo)
 
 		#
 
