@@ -4,7 +4,7 @@
 # imports.
 from ssht00ls.classes.config import *
 from ssht00ls.classes import utils
-from ssht00ls.classes.smart_cards import smart_cards
+from ssht00ls.classes.smartcards import smartcards
 
 # the scp object class.
 class SCP(object):
