@@ -7,17 +7,41 @@ import ssht00ls.classes.ssh.utils as ssh_utils
 
 # the ssh object class.
 class SSH(object):
-	def __init__(self):
+	def __init__(self,
+		# initialize as specific not global (optional).
+		# 	the alias.
+		alias=None,
+	):
+
+		# defaults.
 		self.utils = ssh_utils
+
+		# specific args.
+		self.specific = alias != None
+		self.alias = alias
+
+		#
 	def session(self, 
 		alias=None,
 	):
+
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+
+		# checks.
 		response = r3sponse.check_parameters({
 			"alias":alias,
 		})
 		if not response.success: return response
+
+		# session.
 		os.system(f"ssh {DEFAULT_SSH_OPTIONS} {alias}")
+
+		# handler.
 		return r3sponse.success(f"Successfully started ssh session [{alias}].")
+
+		#
 	def command(self,
 		# the alias.
 		alias=None,
@@ -28,11 +52,19 @@ class SSH(object):
 		# the log level.
 		log_level=0,
 	):
+		
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+
+		# checks.
 		response = r3sponse.check_parameters({
 			"alias":alias,
 			"command":command,
 		})
 		if not response.success: return response
+
+		# command.
 		response = self.utils.execute(
 			command=f"""ssh {DEFAULT_SSH_OPTIONS} {alias} ' {command} ' """,
 			message=f"Successfully executed the command on remote [{alias}].",
@@ -40,10 +72,11 @@ class SSH(object):
 			log_level=log_level,
 			get_output=True,
 			serialize=serialize,)
-		if response.success: 
-			print(response.output)
-		else:
-			print(response.error)
+
+		# handler.
+		if log_level >= 0:
+			if response.success: print(response.output)
+			else: print(response.error)
 		return response
 		
 # initialized objects.
