@@ -4,7 +4,7 @@
 # imports.
 from ssht00ls.classes.config import *
 from ssht00ls.classes import utils
-from ssht00ls.classes.smart_cards import smart_cards
+from ssht00ls.classes.smartcards import smartcards
 from ssht00ls.classes.installation import installation
 
 # the sshd object class.
@@ -84,7 +84,7 @@ class SSHD(object):
 		configuration += '\nMaxAuthTries 3'
 		configuration += '\nMaxSessions 10'
 		configuration += "\nMaxStartups 999"
-		configuration += '\nLogLevel VERBOSE'
+		configuration += '\nLogLevel VERBsyst3m.defaults.vars.osE'
 		configuration += f'\nPort {port}'
 		configuration += '\nProtocol 2'
 
@@ -186,7 +186,7 @@ class SSHD(object):
 		configuration += '\n    PasswordAuthentication no'
 		configuration += '\n    PermitEmptyPasswords no'
 		configuration += '\n    PubkeyAuthentication no'
-		configuration += f'\n    ForceCommand .ssh/utils/log.py "You are not authorized to access user [$USER] over ssh."'
+		configuration += f'\n    ForceCommand .ssh/utils/log.py "You are not authorized to access user [$syst3m.defaults.vars.user] over ssh."'
 		configuration += "\n"
 
 		# save sshd.
@@ -254,14 +254,14 @@ class SSHD(object):
 		for username in usernames:
 			
 			# non existant.
-			fp = FilePath(f"{HOME_BASE}{username}/.ssh/utils/.version")
+			fp = FilePath(f"{syst3m.defaults.vars.homes}{username}/.ssh/utils/.version.py")
 			if not fp.exists(sudo=True): 
 				to_install.append(username)
 
 			# check version.
 			else: 
 				version = utils.__execute__(["sudo", "cat", fp.path])
-				github_version = utils.__execute__(["curl", "https://raw.githubusercontent.com/vandenberghinc/ssht00ls/master/ssht00ls/classes/utils/.version?raw=true"])
+				github_version = utils.__execute__(["curl", "https://raw.githubusercontent.com/vandenberghinc/ssht00ls/master/ssht00ls/classes/utils/.version.py?raw=true"])
 				if str(version) != str(github_version):
 					to_install.append(username)
 
@@ -306,7 +306,7 @@ class SSHD(object):
 				if response["error"] != None: return response
 
 			# copy.
-			fp = FilePath(f"{HOME_BASE}{username}/.ssh/utils/")
+			fp = FilePath(f"{syst3m.defaults.vars.homes}{username}/.ssh/utils/")
 			os.system(f"sudo rm -fr {fp.path}")
 			os.system(f"sudo rsync -az {utils_tmp} {fp.path} --delete")
 			fp.ownership.set(owner=username, group=None, sudo=True, recursive=True)
@@ -332,7 +332,7 @@ class SSHD(object):
 
 		# iterate.
 		for username in usernames:
-			fp = FilePath(f"/{HOME_BASE}{username}/.ssh/banner")
+			fp = FilePath(f"/{syst3m.defaults.vars.homes}{username}/.ssh/banner")
 			file.file_path.copy(fp.path, sudo=True)
 			fp.permission.set(permission=755, sudo=True)
 			fp.ownership.set(owner=username, group=None, sudo=True)
