@@ -12,13 +12,20 @@ from ssht00ls.classes import utils
 
 # the ssync object class.
 class SSync(object):
-	def __init__(self):
+	def __init__(self, 
+		# initialize as specific not global (optional).
+		#	the username.
+		alias=None,
+	):
+
+		# specific args.
+		self.specific = alias != None
+		self.alias = alias
+
+		# defaults.
 		self.utils = ssync_utils
 		self.daemons = daemons
 		if CHECKS and INTERACTIVE:
-			if encryption.activated:
-				response = aliases.sync()
-				if not response["success"]: response.crash(json=JSON)
 			if not cl1.argument_present("--reset-cache"):
 				daemons.sync()
 	def mount(self, 
@@ -40,6 +47,10 @@ class SSync(object):
 		mode="mount",
 	):
 
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+
 		# checks.
 		response = r3sponse.check_parameters({
 			"path:str":path,
@@ -147,6 +158,10 @@ class SSync(object):
 		#
 	def index(self, path=None, alias=None, log_level=0, checks=True, accept_new_host_keys=True):
 
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+
 		# checks.
 		if path == None:
 			return r3sponse.error(f"Define parameter: path.")
@@ -167,7 +182,7 @@ class SSync(object):
 				if not response["success"]: return response
 
 				# check passphrase.
-				if CONFIG["aliases"][alias]["smart_card"] in [True, "true", "True"]:
+				if CONFIG["aliases"][alias]["smartcard"] in [True, "true", "True"]:
 					response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
 				else:
 					response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
@@ -204,13 +219,13 @@ class SSync(object):
 
 			#
 	def set_mounted_icon(self, path):
-		if OS in ["osx", "macos"]:
+		if syst3m.defaults.vars.os in ["osx", "macos"]:
 			#os.system(f"cp '{SOURCE_PATH}/static/media/icons/Icon\r' '{path}/Icon\r'")
 			icon = f'{SOURCE_PATH}/static/media/icons/mounted.png'
 			syst3m.utils.__execute_script__(f"""
 				
 				#!/bin/bash
-				# Set Icon to a File / Folder on macOS
+				# Set Icon to a File / Folder on macsyst3m.defaults.vars.os
 
 				icon="{icon}"
 				dest="{path}"
@@ -282,20 +297,30 @@ class SSync(object):
 		# get the command in str.
 		command=False,
 	):	
+
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+
 		# check encryption activated.
 		if not encryption.activated:
 			return r3sponse.error("The encryption requires to be activated.")
 		if checks:
-			if CONFIG["aliases"][alias]["smart_card"] in [True, "true", "True"]:
-				response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
-			else:
-				response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
-			if not response["success"]: return response
-			passphrase = response.decrypted.decode()
-			response = aliases.check(alias)
-			if not response["success"]: return response
-			response = agent.add(path=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
-			if not response["success"]: return response
+			if self.specific:
+				try: self.activated
+				except: self.activated = False
+			if not self.specific or not self.activated:
+				if CONFIG["aliases"][alias]["smartcard"] in [True, "true", "True"]:
+					response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
+				else:
+					response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
+				if not response["success"]: return response
+				passphrase = response.decrypted.decode()
+				response = aliases.check(alias)
+				if not response["success"]: return response
+				response = agent.add(path=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
+				if not response["success"]: return response
+				if self.specific: self.activated = True
 		return self.utils.pull(
 			# the local path.
 			path=path, 
@@ -344,25 +369,36 @@ class SSync(object):
 		accept_new_host_keys=True,
 		# checks.
 		checks=True,
+		check_base=True,
 		# log level.
 		log_level=0,
 		# get the command in str.
 		command=False,
 	):
+
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+
 		# check encryption activated.
 		if not encryption.activated:
 			return r3sponse.error("The encryption requires to be activated.")
 		if checks:
-			if CONFIG["aliases"][alias]["smart_card"] in [True, "true", "True"]:
-				response = encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
-			else:
-				response = encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
-			if not response["success"]: return response
-			passphrase = response.decrypted.decode()
-			response = aliases.check(alias)
-			if not response["success"]: return response
-			response = agent.add(path=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
-			if not response["success"]: return response
+			if self.specific:
+				try: self.activated
+				except: self.activated = False
+			if not self.specific or not self.activated:
+				if CONFIG["aliases"][alias]["smartcard"] in [True, "true", "True"]:
+					response = encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
+				else:
+					response = encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
+				if not response["success"]: return response
+				passphrase = response.decrypted.decode()
+				response = aliases.check(alias)
+				if not response["success"]: return response
+				response = agent.add(path=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
+				if not response["success"]: return response
+				if self.specific: self.activated = True
 		return self.utils.push(
 			# the local path.
 			path=path, 
@@ -385,6 +421,7 @@ class SSync(object):
 			accept_new_host_keys=accept_new_host_keys,
 			# checks.
 			checks=checks,
+			check_base=check_base,
 			# log level.
 			log_level=log_level,
 			# get the command in str.
@@ -410,6 +447,11 @@ class SSync(object):
 		# serialized.
 		serialized={},
 	):
+		# check specific.
+		if self.specific:
+			if alias == None: alias = self.alias
+
+		# serialzied.
 		if serialized != {}:
 			alias, remote, path, start, mode, log_level, sandbox, sleeptime = Dictionary(path=False, dictionary=serialized).unpack({
 				"alias":None,
