@@ -69,7 +69,7 @@ def pull(
 	# checks.
 	checks=True,
 	# log level.
-	log_level=LOG_LEVEL,
+	log_level=syst3m.defaults.options.log_level,
 	# get the command in str.
 	command=False,
 ):	
@@ -89,7 +89,7 @@ def pull(
 		#	return r3sponse.error("The encryption requires to be activated.")
 
 		# check passphrase.
-		#if CONFIG["aliases"][alias]["smart_card"] in [True, "true", "True"]:
+		#if CONFIG["aliases"][alias]["smartcard"] in [True, "true", "True"]:
 		#	response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
 		#else:
 		#	response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
@@ -177,8 +177,9 @@ def push(
 	accept_new_host_keys=True,
 	# checks.
 	checks=True,
+	check_base=True,
 	# log level.
-	log_level=LOG_LEVEL,
+	log_level=syst3m.defaults.options.log_level,
 	# get the command in str.
 	command=False,
 ):
@@ -198,7 +199,7 @@ def push(
 		#	return r3sponse.error("The encryption requires to be activated.")
 		
 		# check passphrase.
-		#if CONFIG["aliases"][alias]["smart_card"] in [True, "true", "True"]:
+		#if CONFIG["aliases"][alias]["smartcard"] in [True, "true", "True"]:
 		#	response = encrypion.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
 		#else:
 		#	response = encrypion.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
@@ -221,9 +222,10 @@ def push(
 	# check remote base.
 	# must be excluded from the checks == False.
 	base = FilePath(remote).base(back=1)
-	response = ssh.utils.test_dir(alias=alias, path=base, accept_new_host_keys=accept_new_host_keys, create=True, checks=False)
-	if not response.success: return response
-	if response.created and log_level >= 3: print(f"Created remote directory {base}.")
+	if check_base:
+		response = ssh.utils.test_dir(alias=alias, path=base, accept_new_host_keys=accept_new_host_keys, create=True, checks=False)
+		if not response.success: return response
+		if response.created and log_level >= 3: print(f"Created remote directory {base}.")
 
 	# options.
 	exclude_str = Array(array=exclude).string(joiner=" --exclude ", sum_first=True)
